@@ -1,9 +1,9 @@
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 try:
     from .utils import gauge, metric
     # placate pyflakes
     assert gauge
     assert metric
-except ImportError:
-    pass
+except ImportError:  # pragma: no cover
+    pass  # pragma: no cover
